PDC (Proactive Data Containers) is a software-defined data management system meant for high performance computing systems with several layers of storage, aiming to minimize overhead of moving data between memory and storage layers.

Its existing interface is written in C, but with the rise of Python in scientific computing applications, PDC would be much more accessible with a python interface.

This repository contains that interface, its documentation, and unit tests.

This project is part of [Google Summer of Code 2022](https://summerofcode.withgoogle.com/programs/2022) ([project page](https://summerofcode.withgoogle.com/programs/2022/projects/aXtefGUz))

Thanks to [Houjun Tang](https://github.com/houjun) for answering my questions about PDC while developing the project.

Thanks to [CROSS](https://cross.ucsc.edu/) for supporting PDC.

[More information about PDC](https://sdm.lbl.gov/pdc/about.html)

[Documentation](https://hpc-io.github.io/PDCpy/)
